@@ -26,3 +26,7 @@ class Countries:
         formatted_string = json.dumps(json_data, indent=2)
         return formatted_string
 
+
+if __name__ == '__main__':
+    api = Countries()
+    print(api.get_region_details("US", "CA"))
