@@ -14,11 +14,11 @@ class Translator:
                 "X-RapidAPI-Key": "9956beec72msh8f5b5e09b33da88p1d8b8cjsneac0d0fcdcea"
         }
 
-    def translate_text(self, text, target_lang):
+    def translate_text(self, text, source_lang, target_lang):
         payload = "q=" + text
         payload.replace(" ", "%20")
         payload.replace(",", "%2C")
-        payload += ("&target=" + target_lang + "&source=en")
+        payload += ("&target=" + target_lang + "&source=" + source_lang)
         response = requests.request("POST", self.url, data=payload, headers=self.headers)
         json_data = json.loads(response.text)
         formatted_string = json.dumps(json_data, indent=2)
